EXPORTS
	??0RScsClientBase@@IAE@XZ @ 1 NONAME ; RScsClientBase::RScsClientBase(void)
	??0RScsClientSubsessionBase@@IAE@XZ @ 2 NONAME ; RScsClientSubsessionBase::RScsClientSubsessionBase(void)
	?Close@RScsClientSubsessionBase@@QAEXXZ @ 3 NONAME ; void RScsClientSubsessionBase::Close(void)
	?Connect@RScsClientBase@@IAEHABVTDesC16@@ABVTVersion@@0ABVTUidType@@@Z @ 4 NONAME ; int RScsClientBase::Connect(class TDesC16 const &, class TVersion const &, class TDesC16 const &, class TUidType const &)
	?CreateSubsession@RScsClientSubsessionBase@@IAEHABVRScsClientBase@@HABVTIpcArgs@@@Z @ 5 NONAME ; int RScsClientSubsessionBase::CreateSubsession(class RScsClientBase const &, int, class TIpcArgs const &)
	?ResetServerHeapFail@RScsClientBase@@QAEHXZ @ 6 NONAME ; TInt RScsClientBase::ResetServerHeapFail(void)
	?CallSessionFunction@RScsClientBase@@IBEHH@Z @ 7 NONAME ; int RScsClientBase::CallSessionFunction(int) const
	?CallSessionFunction@RScsClientBase@@IBEHHABVTIpcArgs@@@Z @ 8 NONAME ; int RScsClientBase::CallSessionFunction(int, class TIpcArgs const &) const
	?CallSubsessionFunction@RScsClientSubsessionBase@@IBEHH@Z @ 9 NONAME ; int RScsClientSubsessionBase::CallSubsessionFunction(int) const
	?CallSubsessionFunction@RScsClientSubsessionBase@@IBEHHABVTIpcArgs@@@Z @ 10 NONAME ; int RScsClientSubsessionBase::CallSubsessionFunction(int, class TIpcArgs const &) const
	?SetServerHeapFail@RScsClientBase@@QAEHH@Z @ 11 NONAME ; TInt RScsClientBase::SetServerHeapFail(int)
	?CallSessionFunction@RScsClientBase@@IBEXHABVTIpcArgs@@AAVTRequestStatus@@@Z @ 12 NONAME ; void RScsClientBase::CallSessionFunction(int, class TIpcArgs const &, class TRequestStatus &) const
	?CancelSessionFunction@RScsClientBase@@IBEXH@Z @ 13 NONAME ; void RScsClientBase::CancelSessionFunction(int) const
	?CallSubsessionFunction@RScsClientSubsessionBase@@IBEXHABVTIpcArgs@@AAVTRequestStatus@@@Z @ 14 NONAME ; void RScsClientSubsessionBase::CallSubsessionFunction(int, class TIpcArgs const &, class TRequestStatus &) const
	?CancelSubsessionFunction@RScsClientSubsessionBase@@IBEXH@Z @ 15 NONAME ; void RScsClientSubsessionBase::CancelSubsessionFunction(int) const
	?Close@RScsClientBase@@QAEXXZ @ 16 NONAME ; void RScsClientBase::Close(void)
	?ShutdownServer@RScsClientBase@@QAEHXZ @ 17 NONAME ; int RScsClientBase::ShutdownServer(void)

